%global versuf rc4
%global uuid org.%{name}.Alacritty

Name: alacritty
Version: 0.11.0
Release: 2%{?dist}
Summary: Cross-platform, OpenGL terminal emulator

License: ASL 2.0
URL: https://github.com/alacritty/alacritty
Source0: %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires: cargo >= 1.57.0
BuildRequires: cmake
BuildRequires: desktop-file-utils
BuildRequires: expat-devel
BuildRequires: fontconfig-devel
BuildRequires: freetype-devel
BuildRequires: gcc-c++
BuildRequires: libappstream-glib
BuildRequires: libxcb-devel
BuildRequires: ncurses
BuildRequires: python3-devel
BuildRequires: rust >= 1.57.0

%if 0%{?fedora} < 33
# FIXME: workaround for 'ncurses-term' conflict
Recommends: %{name}-terminfo = %{version}-%{release}
%endif

%if 0%{?fedora} >= 33
Obsoletes: %{name}-terminfo
%endif

%description
Alacritty - A fast, cross-platform, OpenGL terminal emulator

Alacritty is a modern terminal emulator that comes with sensible defaults, but
allows for extensive configuration. By integrating with other applications,
rather than reimplementing their functionality, it manages to provide a
flexible set of features with high performance. The supported platforms
currently consist of BSD, Linux, macOS and Windows.

The software is considered to be at a beta level of readiness; there are a few
missing features and bugs to be fixed, but it is already used by many as a
daily driver.



%prep
%autosetup -n %{name}-%{version} -p1


%build
export CARGO_PROFILE_RELEASE_BUILD_OVERRIDE_OPT_LEVEL=3
cargo build --release


%install
install -pDm 0755 target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -pDm 0644 extra/%{name}.man %{buildroot}%{_mandir}/man1/%{name}.1
install -pDm 0644 extra/completions/_%{name} %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -pDm 0644 extra/completions/%{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -pDm 0644 extra/completions/%{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -pDm 0644 extra/linux/%{uuid}.appdata.xml %{buildroot}%{_metainfodir}/%{uuid}.appdata.xml
install -pDm 0644 extra/linux/Alacritty.desktop %{buildroot}%{_datadir}/applications/Alacritty.desktop
install -pDm 0644 extra/logo/%{name}-term.svg %{buildroot}%{_datadir}/pixmaps/Alacritty.svg


%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop


%files
%license LICENSE-APACHE
%doc README.md CHANGELOG.md CONTRIBUTING.md %{name}.yml
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/fish/vendor_completions.d/%{name}.fish
%{_datadir}/pixmaps/*.svg
%{_datadir}/zsh/site-functions/_%{name}
%{_mandir}/man1/*.1*
%{_metainfodir}/*.xml



%changelog
* Thu Oct 13 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.11.0-1
- chore(update): 0.11.0

* Mon Feb 21 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.10.1-1
- chore(update): 0.10.1

* Mon Jan 24 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.10.0-1
- chore(update): 0.10.0

* Wed May 19 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.8.0-1
- build(update): 0.8.0

* Sat Feb 20 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.7.2-1
- build(update): 0.7.2

* Sat Jan  9 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.7.1-1
- build(update): 0.7.1

* Fri Jan  8 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.7.0-1
- build(update): 0.7.0

* Wed Nov 25 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.6.0-1
- build(update): 0.6.0

* Sat Aug 01 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.5.0-1
- Update to 0.5.0

* Mon Jun 01 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.3-1
- Update to 0.4.3

* Mon Mar 30 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.2-1
- Update to 0.4.2

* Tue Mar 24 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.2-0.1.rc4
- Update to 0.4.2-rc4

* Mon Mar 23 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.2-0.1.rc3
- Update to 0.4.2-rc3

* Thu Jan 09 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.1-1
- Update to 0.4.1

* Thu Jan 09 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.1-0.1.rc3
- Update to 0.4.1-rc3

* Thu Dec 05 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.0-2
- Move configuration file into docs dir as it recommended by upstream now

* Mon Nov 25 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.0-1
- Update to 0.4.0

* Fri Nov 22 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.0-0.3rc4
- Update to 0.4.0-rc4

* Fri Nov 22 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.0-0.2rc3
- Update to 0.4.0-rc3

* Tue Nov 19 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.0-0.1rc2
- Update to 0.4.0-rc2

* Wed Oct 30 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.3.3-3
- Minor spec file changes
